@@ -11,9 +11,9 @@ except ImportError:
     # NOTE - could use subprocess to get from git?
     __rev__ = "local"
 
-__version__ = "0.8.1"
+__version__ = "0.9.0"
 
-TEST_ENV: bool = "DP_TEST_ENV" in os.environ
+TEST_ENV = bool(os.environ.get("DP_TEST_ENV", ""))
 
 # Other useful re-exports
 from .common.utils import log, _setup_dp_logging
@@ -22,22 +22,34 @@ from .common.utils import log, _setup_dp_logging
 from .client.api import (
     Blocks,
     Blob,
+    BigNumber,
+    Code,
+    DataTable,
+    Group,
     File,
+    HTML,
+    Text,
     Markdown,
+    Page,
     Params,
     Plot,
     Report,
     Result,
     Run,
-    Script,
     Schedule,
+    Script,
+    Select,
+    SelectType,
     Table,
+    Text,
     Variable,
+    Visibility,
     by_datapane,
     login,
     logout,
     on_datapane,
     ping,
+    templates,
 )
 from .client.config import init
 from .common.dp_types import DPMode, set_dp_mode, get_dp_mode
@@ -52,12 +64,13 @@ elif by_datapane or script_exe == "dp-runner":
 else:
     set_dp_mode(DPMode.LIBRARY)
 
-
 # TODO - do we want to init only in jupyter / interactive / etc.
 # only init fully in library-mode, as framework and app init explicitly
 if get_dp_mode() == DPMode.LIBRARY:
     init()
     # parse any command0line params
     from .client.utils import parse_command_line
+    from .client.api.runtime import Params
 
-    parse_command_line()
+    config = parse_command_line()
+    Params.replace(config)
