@@ -1,3 +1,9 @@
+"""## Script runtime API
+
+Runtime API used when running a Datapane Script
+
+..note:: The objects in this module are available on the Teams Plan
+"""
 import dataclasses as dc
 import os
 import typing as t
@@ -15,6 +21,9 @@ if t.TYPE_CHECKING:
 # TODO - make thread/context safe and determine a better approach for vars
 # TODO - add API tests
 
+__all__ = []
+
+
 # we're running on datapane platform
 on_datapane: bool = "DATAPANE_ON_DATAPANE" in os.environ
 # we're running the datapane runner (also checked by __name__ == "__datapane__" in user script)
