@@ -11,9 +11,11 @@ import importlib_resources as ir
 import jsonschema
 import nbconvert
 import nbformat
+import stringcase
 import yaml
 from traitlets.config import Config as TConfig
 
+from datapane.client import DPError
 from datapane.common import SDict, log
 
 # app paths
@@ -21,7 +23,7 @@ DATAPANE_YAML = Path("datapane.yaml")
 PYPROJECT_TOML = Path("pyproject.toml")
 DEFAULT_PY = Path("dp_script.py")
 DEFAULT_IPYNB = Path("dp_script.ipynb")
-re_check_name = re.compile(r"^\w+$")
+re_check_name = re.compile(r"^[\S ]+$")
 
 # TODO - look at other libs
 #  - https://lidatong.github.io/dataclasses-json/ (or marshmallow)
@@ -34,13 +36,15 @@ re_check_name = re.compile(r"^\w+$")
 #  - convert notebook (use 1st markdown as docstring?)
 
 
+def generate_name(postfix: str) -> str:
+    dir_name = stringcase.titlecase(os.path.basename(os.getcwd()))
+    return f"{dir_name} {postfix}"
+
+
+# TODO(obsolete) - not really needed now, can remove in future
 def validate_name(x: str):
     if re_check_name.match(x) is None:
-        raise AssertionError(f"'{x}' is not a valid service name, must be [a-z0-9-_]")
-
-
-def default_title() -> str:
-    return "New Untitled Script"
+        raise DPError(f"'{x}' is not a valid service name")
 
 
 @dc.dataclass
@@ -49,9 +53,7 @@ class DatapaneCfg:
 
     name: str = "datapane"
     # relative path to script
-    script: Path = dc.field(
-        default_factory=lambda: DEFAULT_IPYNB if DEFAULT_IPYNB.exists() else DEFAULT_PY
-    )
+    script: Path = dc.field(default_factory=lambda: DEFAULT_IPYNB if DEFAULT_IPYNB.exists() else DEFAULT_PY)
     config: dc.InitVar[Path] = None
     proj_dir: ClassVar[Path] = None
 
@@ -63,9 +65,8 @@ class DatapaneCfg:
     post_commands: List[str] = dc.field(default_factory=list)
 
     # metadata
-    title: str = dc.field(default_factory=default_title)
     description: str = "Datapane Script"
-    repo: str = ""
+    source_url: str = ""
     visibility: Optional[str] = None
 
     # build options
@@ -79,9 +80,7 @@ class DatapaneCfg:
         # TODO - support running config/script from another dir with abs paths
         # all paths are relative and we're running from the same dir
         if config:
-            assert (
-                config.parent == self.script.parent == Path(".")
-            ), "All files must be in the main project directory"
+            assert config.parent == self.script.parent == Path("."), "All files must be in the main project directory"
         # we must be in the project dir for now
         # TODO - move this logic to create_initial
         self.proj_dir = self.script.resolve(strict=False).parent
@@ -94,9 +93,7 @@ class DatapaneCfg:
 
         # validate config
         if self.parameters:
-            config_schema = json.loads(
-                ir.read_text("datapane.resources", "script_parameter_def.schema.json")
-            )
+            config_schema = json.loads(ir.read_text("datapane.resources", "script_parameter_def.schema.json"))
             jsonschema.validate(self.parameters, config_schema)
 
     @classmethod
